==> libad9361-0.2-4-x86_64.pkg.tar.zst: usr/share/doc/ad93610-doc/html/search/functions_0.js <==
var searchData=
[
  ['ad9361_5fcalculate_5frf_5fclock_5fchain_42',['ad9361_calculate_rf_clock_chain',['../group__TopLevel.html#gae4eb2d63350b1903612e603cab13356d',1,'ad9361_calculate_rf_clock_chain(unsigned long tx_sample_rate, unsigned long rate_gov, unsigned long *rx_path_clks, unsigned long *tx_path_clks):&#160;ad9361_calculate_rf_clock_chain.c'],['../group__TopLevel.html#gae4eb2d63350b1903612e603cab13356d',1,'ad9361_calculate_rf_clock_chain(unsigned long sample_rate, unsigned long rate_gov, unsigned long *rx_path_clks, unsigned long *tx_path_clks):&#160;ad9361_calculate_rf_clock_chain.c']]],
  ['ad9361_5fcalculate_5frf_5fclock_5fchain_5ffdp_43',['ad9361_calculate_rf_clock_chain_fdp',['../group__TopLevel.html#ga1dcf9c46eda4138d24dd279b30d13d40',1,'ad9361_calculate_rf_clock_chain_fdp(struct filter_design_parameters *fdpTX, struct filter_design_parameters *fdpRX, unsigned long sample_rate):&#160;ad9361_design_taps.c'],['../group__TopLevel.html#ga1dcf9c46eda4138d24dd279b30d13d40',1,'ad9361_calculate_rf_clock_chain_fdp(struct filter_design_parameters *fdpTX, struct filter_design_parameters *fdpRX, unsigned long sample_rate):&#160;ad9361_design_taps.c']]],
  ['ad9361_5ffmcomms5_5fmultichip_5fsync_44',['ad9361_fmcomms5_multichip_sync',['../group__TopLevel.html#ga8397091642a76a1e7896cbceaa4ac7fc',1,'ad9361_fmcomms5_multichip_sync(struct iio_context *ctx, unsigned int flags):&#160;ad9361_multichip_sync.c'],['../group__TopLevel.html#ga8397091642a76a1e7896cbceaa4ac7fc',1,'ad9361_fmcomms5_multichip_sync(struct iio_context *ctx, unsigned int flags):&#160;ad9361_multichip_sync.c']]],
  ['ad9361_5ffmcomms5_5fphase_5fsync_45',['ad9361_fmcomms5_phase_sync',['../group__TopLevel.html#gaeeb859740d88a808adc2dcc41c473495',1,'ad9361_fmcomms5_phase_sync(struct iio_context *ctx, long long lo):&#160;ad9361_fmcomms5_phase_sync.c'],['../group__TopLevel.html#gaeeb859740d88a808adc2dcc41c473495',1,'ad9361_fmcomms5_phase_sync(struct iio_context *ctx, long long lo):&#160;ad9361_fmcomms5_phase_sync.c']]],
  ['ad9361_5fgenerate_5ffir_5ftaps_46',['ad9361_generate_fir_taps',['../group__TopLevel.html#ga60ac5c3f6a5087faa3ab07edb645b874',1,'ad9361_generate_fir_taps(struct filter_design_parameters *parameters, short *taps, int *num_taps, int *gain):&#160;ad9361_design_taps.c'],['../group__TopLevel.html#ga60ac5c3f6a5087faa3ab07edb645b874',1,'ad9361_generate_fir_taps(struct filter_design_parameters *parameters, short *taps, int *num_taps, int *gain):&#160;ad9361_design_taps.c']]],
  ['ad9361_5fget_5ftrx_5ffir_5fenable_47',['ad9361_get_trx_fir_enable',['../group__TopLevel.html#ga8c0aa6b86ce0fe5a4d56034f691994ed',1,'ad9361_get_trx_fir_enable(struct iio_device *dev, int *enable):&#160;ad9361_baseband_auto_rate.c'],['../group__TopLevel.html#ga8c0aa6b86ce0fe5a4d56034f691994ed',1,'ad9361_get_trx_fir_enable(struct iio_device *dev, int *enable):&#160;ad9361_baseband_auto_rate.c']]],
  ['ad9361_5fmultichip_5fsync_48',['ad9361_multichip_sync',['../group__TopLevel.html#ga02f886c4f51656d4ba7eb14cc4c45260',1,'ad9361_multichip_sync(struct iio_device *master, struct iio_device **slaves, unsigned int num_slaves, unsigned int flags):&#160;ad9361_multichip_sync.c'],['../group__TopLevel.html#ga02f886c4f51656d4ba7eb14cc4c45260',1,'ad9361_multichip_sync(struct iio_device *master, struct iio_device **slaves, unsigned int num_slaves, unsigned int flags):&#160;ad9361_multichip_sync.c']]],
  ['ad9361_5fset_5fbb_5frate_49',['ad9361_set_bb_rate',['../group__TopLevel.html#ga56c31cc700d410be9bdeea3040e62eb3',1,'ad9361_set_bb_rate(struct iio_device *dev, unsigned long rate):&#160;ad9361_baseband_auto_rate.c'],['../group__TopLevel.html#ga56c31cc700d410be9bdeea3040e62eb3',1,'ad9361_set_bb_rate(struct iio_device *dev, unsigned long rate):&#160;ad9361_baseband_auto_rate.c']]],
  ['ad9361_5fset_5fbb_5frate_5fcustom_5ffilter_5fauto_50',['ad9361_set_bb_rate_custom_filter_auto',['../group__TopLevel.html#gae31709100b0e132289bce9f4c0d475fd',1,'ad9361_set_bb_rate_custom_filter_auto(struct iio_device *dev, unsigned long rate):&#160;ad9361_design_taps.c'],['../group__TopLevel.html#gae31709100b0e132289bce9f4c0d475fd',1,'ad9361_set_bb_rate_custom_filter_auto(struct iio_device *dev, unsigned long rate):&#160;ad9361_design_taps.c']]],
  ['ad9361_5fset_5fbb_5frate_5fcustom_5ffilter_5fmanual_51',['ad9361_set_bb_rate_custom_filter_manual',['../group__TopLevel.html#gafbdf950c341eb7df148a81836ad5dc2c',1,'ad9361_set_bb_rate_custom_filter_manual(struct iio_device *dev, unsigned long rate, unsigned long Fpass, unsigned long Fstop, unsigned long wnom_tx, unsigned long wnom_rx):&#160;ad9361_design_taps.c'],['../group__TopLevel.html#gafbdf950c341eb7df148a81836ad5dc2c',1,'ad9361_set_bb_rate_custom_filter_manual(struct iio_device *dev, unsigned long rate, unsigned long Fpass, unsigned long Fstop, unsigned long wnom_tx, unsigned long wnom_rx):&#160;ad9361_design_taps.c']]],
  ['ad9361_5fset_5ftrx_5ffir_5fenable_52',['ad9361_set_trx_fir_enable',['../group__TopLevel.html#ga45ccd7e395de4080c7d6b76a46f1bee5',1,'ad9361_set_trx_fir_enable(struct iio_device *dev, int enable):&#160;ad9361_baseband_auto_rate.c'],['../group__TopLevel.html#ga45ccd7e395de4080c7d6b76a46f1bee5',1,'ad9361_set_trx_fir_enable(struct iio_device *dev, int enable):&#160;ad9361_baseband_auto_rate.c']]]
];

==> libad9361-0.2-5-x86_64.pkg.tar.zst: usr/share/doc/ad93610-doc/html/search/functions_0.js <==
var searchData=
[
  ['ad9361_5fcalculate_5frf_5fclock_5fchain_42',['ad9361_calculate_rf_clock_chain',['../group__TopLevel.html#gae4eb2d63350b1903612e603cab13356d',1,'ad9361_calculate_rf_clock_chain(unsigned long sample_rate, unsigned long rate_gov, unsigned long *rx_path_clks, unsigned long *tx_path_clks):&#160;ad9361_calculate_rf_clock_chain.c'],['../group__TopLevel.html#gae4eb2d63350b1903612e603cab13356d',1,'ad9361_calculate_rf_clock_chain(unsigned long tx_sample_rate, unsigned long rate_gov, unsigned long *rx_path_clks, unsigned long *tx_path_clks):&#160;ad9361_calculate_rf_clock_chain.c']]],
  ['ad9361_5fcalculate_5frf_5fclock_5fchain_5ffdp_43',['ad9361_calculate_rf_clock_chain_fdp',['../group__TopLevel.html#ga1dcf9c46eda4138d24dd279b30d13d40',1,'ad9361_calculate_rf_clock_chain_fdp(struct filter_design_parameters *fdpTX, struct filter_design_parameters *fdpRX, unsigned long sample_rate):&#160;ad9361_design_taps.c'],['../group__TopLevel.html#ga1dcf9c46eda4138d24dd279b30d13d40',1,'ad9361_calculate_rf_clock_chain_fdp(struct filter_design_parameters *fdpTX, struct filter_design_parameters *fdpRX, unsigned long sample_rate):&#160;ad9361_design_taps.c']]],
  ['ad9361_5ffmcomms5_5fmultichip_5fsync_44',['ad9361_fmcomms5_multichip_sync',['../group__TopLevel.html#ga8397091642a76a1e7896cbceaa4ac7fc',1,'ad9361_fmcomms5_multichip_sync(struct iio_context *ctx, unsigned int flags):&#160;ad9361_multichip_sync.c'],['../group__TopLevel.html#ga8397091642a76a1e7896cbceaa4ac7fc',1,'ad9361_fmcomms5_multichip_sync(struct iio_context *ctx, unsigned int flags):&#160;ad9361_multichip_sync.c']]],
  ['ad9361_5ffmcomms5_5fphase_5fsync_45',['ad9361_fmcomms5_phase_sync',['../group__TopLevel.html#gaeeb859740d88a808adc2dcc41c473495',1,'ad9361_fmcomms5_phase_sync(struct iio_context *ctx, long long lo):&#160;ad9361_fmcomms5_phase_sync.c'],['../group__TopLevel.html#gaeeb859740d88a808adc2dcc41c473495',1,'ad9361_fmcomms5_phase_sync(struct iio_context *ctx, long long lo):&#160;ad9361_fmcomms5_phase_sync.c']]],
  ['ad9361_5fgenerate_5ffir_5ftaps_46',['ad9361_generate_fir_taps',['../group__TopLevel.html#ga60ac5c3f6a5087faa3ab07edb645b874',1,'ad9361_generate_fir_taps(struct filter_design_parameters *parameters, short *taps, int *num_taps, int *gain):&#160;ad9361_design_taps.c'],['../group__TopLevel.html#ga60ac5c3f6a5087faa3ab07edb645b874',1,'ad9361_generate_fir_taps(struct filter_design_parameters *parameters, short *taps, int *num_taps, int *gain):&#160;ad9361_design_taps.c']]],
  ['ad9361_5fget_5ftrx_5ffir_5fenable_47',['ad9361_get_trx_fir_enable',['../group__TopLevel.html#ga8c0aa6b86ce0fe5a4d56034f691994ed',1,'ad9361_get_trx_fir_enable(struct iio_device *dev, int *enable):&#160;ad9361_baseband_auto_rate.c'],['../group__TopLevel.html#ga8c0aa6b86ce0fe5a4d56034f691994ed',1,'ad9361_get_trx_fir_enable(struct iio_device *dev, int *enable):&#160;ad9361_baseband_auto_rate.c']]],
  ['ad9361_5fmultichip_5fsync_48',['ad9361_multichip_sync',['../group__TopLevel.html#ga02f886c4f51656d4ba7eb14cc4c45260',1,'ad9361_multichip_sync(struct iio_device *master, struct iio_device **slaves, unsigned int num_slaves, unsigned int flags):&#160;ad9361_multichip_sync.c'],['../group__TopLevel.html#ga02f886c4f51656d4ba7eb14cc4c45260',1,'ad9361_multichip_sync(struct iio_device *master, struct iio_device **slaves, unsigned int num_slaves, unsigned int flags):&#160;ad9361_multichip_sync.c']]],
  ['ad9361_5fset_5fbb_5frate_49',['ad9361_set_bb_rate',['../group__TopLevel.html#ga56c31cc700d410be9bdeea3040e62eb3',1,'ad9361_set_bb_rate(struct iio_device *dev, unsigned long rate):&#160;ad9361_baseband_auto_rate.c'],['../group__TopLevel.html#ga56c31cc700d410be9bdeea3040e62eb3',1,'ad9361_set_bb_rate(struct iio_device *dev, unsigned long rate):&#160;ad9361_baseband_auto_rate.c']]],
  ['ad9361_5fset_5fbb_5frate_5fcustom_5ffilter_5fauto_50',['ad9361_set_bb_rate_custom_filter_auto',['../group__TopLevel.html#gae31709100b0e132289bce9f4c0d475fd',1,'ad9361_set_bb_rate_custom_filter_auto(struct iio_device *dev, unsigned long rate):&#160;ad9361_design_taps.c'],['../group__TopLevel.html#gae31709100b0e132289bce9f4c0d475fd',1,'ad9361_set_bb_rate_custom_filter_auto(struct iio_device *dev, unsigned long rate):&#160;ad9361_design_taps.c']]],
  ['ad9361_5fset_5fbb_5frate_5fcustom_5ffilter_5fmanual_51',['ad9361_set_bb_rate_custom_filter_manual',['../group__TopLevel.html#gafbdf950c341eb7df148a81836ad5dc2c',1,'ad9361_set_bb_rate_custom_filter_manual(struct iio_device *dev, unsigned long rate, unsigned long Fpass, unsigned long Fstop, unsigned long wnom_tx, unsigned long wnom_rx):&#160;ad9361_design_taps.c'],['../group__TopLevel.html#gafbdf950c341eb7df148a81836ad5dc2c',1,'ad9361_set_bb_rate_custom_filter_manual(struct iio_device *dev, unsigned long rate, unsigned long Fpass, unsigned long Fstop, unsigned long wnom_tx, unsigned long wnom_rx):&#160;ad9361_design_taps.c']]],
  ['ad9361_5fset_5ftrx_5ffir_5fenable_52',['ad9361_set_trx_fir_enable',['../group__TopLevel.html#ga45ccd7e395de4080c7d6b76a46f1bee5',1,'ad9361_set_trx_fir_enable(struct iio_device *dev, int enable):&#160;ad9361_baseband_auto_rate.c'],['../group__TopLevel.html#ga45ccd7e395de4080c7d6b76a46f1bee5',1,'ad9361_set_trx_fir_enable(struct iio_device *dev, int enable):&#160;ad9361_baseband_auto_rate.c']]]
];
